Class: ElasticGraph::Apollo::GraphQL::EntitiesFieldResolver::RepresentationWithoutIndex
- Inherits:
-
Object
- Object
- ElasticGraph::Apollo::GraphQL::EntitiesFieldResolver::RepresentationWithoutIndex
- Defined in:
- lib/elastic_graph/apollo/graphql/entities_field_resolver.rb
Instance Method Summary collapse
- #adapter ⇒ Object
-
#customize_query(query, representations) ⇒ Object
:nocov: – these methods are not called on an adapter when ‘root_document_type?` returns `false`.
-
#identify_matching_hit(indexed_search_hits, representation, context:, index:) ⇒ Object
:nocov:.
- #index_search_hits(response) ⇒ Object
- #root_document_type? ⇒ Boolean
Instance Method Details
#adapter ⇒ Object
293 294 295 |
# File 'lib/elastic_graph/apollo/graphql/entities_field_resolver.rb', line 293 def adapter self end |
#customize_query(query, representations) ⇒ Object
:nocov: – these methods are not called on an adapter when ‘root_document_type?` returns `false`.
298 299 300 |
# File 'lib/elastic_graph/apollo/graphql/entities_field_resolver.rb', line 298 def customize_query(query, representations) nil end |
#identify_matching_hit(indexed_search_hits, representation, context:, index:) ⇒ Object
:nocov:
307 308 309 |
# File 'lib/elastic_graph/apollo/graphql/entities_field_resolver.rb', line 307 def identify_matching_hit(indexed_search_hits, representation, context:, index:) representation.representation_hash end |
#index_search_hits(response) ⇒ Object
302 303 304 |
# File 'lib/elastic_graph/apollo/graphql/entities_field_resolver.rb', line 302 def index_search_hits(response) nil end |
#root_document_type? ⇒ Boolean
311 312 313 |
# File 'lib/elastic_graph/apollo/graphql/entities_field_resolver.rb', line 311 def root_document_type? false end |